Crate gospel_dump

Crate gospel_dump 

Pretty nice printing of hex dumps.

This is intended to be used alongside gospel with the Reader::dump function, but can be used with plain byte slices with Dump::new.

See Dump for main documentation.

Structs

Dump
A hex dump of a byte slice.