Pretty nice printing of hex dumps.
This is intended to be used alongside gospel with the Reader::dump function, but can be used with plain byte slices with Dump::new.
gospel
Reader::dump
Dump::new
See Dump for main documentation.
Dump